==> haskell-hslua-module-system-1.1.0.1-22-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              1.1.0.1
visibility:           public
id:                   hslua-module-system-1.1.0.1-KZ1R2hCFqVt6ruh2omN6Bl
key:                  hslua-module-system-1.1.0.1-KZ1R2hCFqVt6ruh2omN6Bl
license:              MIT
copyright:            © 2019-2023 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  6fab8f6e174b885a3c1ac6b019eee322
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-system-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-system-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.0.1-KZ1R2hCFqVt6ruh2omN6Bl
depends:
    base-4.16.4.0 directory-1.3.6.2 exceptions-0.10.4
    hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
    hslua-marshalling-2.3.0-Ig2P4Cxc1BcAg3kht9VCbg
    hslua-packaging-2.3.1-IUoPNcKfN1bCEmWPniFc9y
    temporary-1.3-LhTJC0HpzSoAJPVdFavBZq text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-1.1.0.1-34.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              1.1.0.1
visibility:           public
id:                   hslua-module-system-1.1.0.1-L7dsFEeefJH8gz5ZXh3vFX
key:                  hslua-module-system-1.1.0.1-L7dsFEeefJH8gz5ZXh3vFX
license:              MIT
copyright:            © 2019-2023 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  38cd3be6d2b60c81e85e7f975cd316f0
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-system-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-system-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.0.1-L7dsFEeefJH8gz5ZXh3vFX
depends:
    base-4.16.4.0 directory-1.3.6.2 exceptions-0.10.4
    hslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
    hslua-marshalling-2.3.1-KsyI9r2uX5jHis6xOiGZDK
    hslua-packaging-2.3.1-DcKYMvh8UnK4G3weiYwSG
    temporary-1.3-92h1kCtCGR4FaQHxoGuxwh text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
